==> nextcloud-app-contacts-1.5.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/uk.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Контакти",
    "Download" : "Завантажити",
    "ShowURL" : "Показати URL",
    "Share Addressbook" : "Поділитися адресною книгою",
    "Delete Addressbook" : "Видалити адресну книгу",
    "Share with users or groups" : "Поділитися з користувачем або групою",
    "Delete" : "Видалити",
    "can edit" : "може редагувати",
    "Address book name" : "Назва адресної книги",
    "Import" : "Імпорт",
    "The selected image is too big (max 1MB)" : "Обране зображення занадто велике (1МБ max)",
    "No contacts in here" : "Тут немає контактів",
    "Name" : "Ім’я",
    "Organization" : "Організація",
    "Title" : "Назва",
    "Add field ..." : "Додати поле...",
    "No search result for {query}" : "Немає результатів пошуку для {query}",
    "_%n contact_::_%n contacts_" : ["%n контакт","%n контактів","%n контактів"],
    "Post office box" : "Абонентська скринька",
    "Postal code" : "Поштовий індекс",
    "City" : "Місто",
    "State or province" : "Область або район",
    "Country" : "Країна",
    "Address" : "Адреса",
    "(new group)" : "(нова група)",
    "Last name" : "Прізвище",
    "First name" : "Ім'я",
    "Additional names" : "Додаткові імена",
    "Prefix" : "Префікс",
    "Suffix" : "Суфікс",
    "All contacts" : "Всі контакти",
    "Not grouped" : "Не згруповані",
    "New contact" : "Новий контакт",
    "{addressbook} shared by {owner}" : "{owner} поділився {addressbook}",
    "Contact could not be created." : "Неможливо створити контакт.",
    "No contacts in file. Only VCard files are allowed." : "Відсутні контакти в фалі. Дозволено лише VCard.",
    "Only VCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Підтримується лише VCard версії 4.0 (RFC6350) або версії 3.0 (RFC2426).",
    "Nickname" : "Прізвисько",
    "Detailed name" : "Повне ім'я",
    "Notes" : "Нотатки",
    "Website" : "Web-сайт",
    "Federated Cloud ID" : "Об'єднаний Хмарний Ідентіфікатор",
    "Home" : "Домашня адреса",
    "Work" : "Робота",
    "Other" : "Інше",
    "Groups" : "Групи",
    "Birthday" : "День народження",
    "Anniversary" : "Річниця",
    "Date of death" : "Дата смерті",
    "Email" : "E-mail",
    "Instant messaging" : "Швидкі повідомлення",
    "Phone" : "Телефон",
    "Mobile" : "Мобільний",
    "Fax" : "Факс",
    "Fax home" : "Домашній факс",
    "Fax work" : "Робочий факс",
    "Pager" : "Пейджер",
    "Voice" : "Голос",
    "Social network" : "Соціальна мережа",
    "Settings" : "Налаштування"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-app-contacts-2.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/uk.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Контакти",
    "Download" : "Завантажити",
    "Delete" : "Видалити",
    "Share with users or groups" : "Поділитися з користувачем або групою",
    "can edit" : "може редагувати",
    "Address book name" : "Назва адресної книги",
    "The selected image is too big (max 1MB)" : "Обране зображення занадто велике (1МБ max)",
    "No contacts in here" : "Тут немає контактів",
    "Name" : "Ім’я",
    "Organization" : "Організація",
    "Title" : "Назва",
    "Save changes" : "Зберегти зміни",
    "No search result for {query}" : "Немає результатів пошуку для {query}",
    "All contacts" : "Всі контакти",
    "Post office box" : "Абонентська скринька",
    "Postal code" : "Поштовий індекс",
    "City" : "Місто",
    "State or province" : "Область або район",
    "Country" : "Країна",
    "Address" : "Адреса",
    "(new group)" : "(нова група)",
    "Last name" : "Прізвище",
    "First name" : "Ім'я",
    "Additional names" : "Додаткові імена",
    "Prefix" : "Префікс",
    "Suffix" : "Суфікс",
    "New contact" : "Новий контакт",
    "Not grouped" : "Не згруповані",
    "Sort by" : "Сортувати за",
    "{addressbook} shared by {owner}" : "{owner} поділився {addressbook}",
    "Contact could not be created." : "Неможливо створити контакт.",
    "Display name" : "Ім'я для відображення",
    "Nickname" : "Прізвисько",
    "Detailed name" : "Повне ім'я",
    "Notes" : "Нотатки",
    "Website" : "Web-сайт",
    "Federated Cloud ID" : "Об'єднаний Хмарний Ідентіфікатор",
    "Home" : "Домашня адреса",
    "Work" : "Робота",
    "Other" : "Інше",
    "Groups" : "Групи",
    "Birthday" : "День народження",
    "Anniversary" : "Річниця",
    "Date of death" : "Дата смерті",
    "Email" : "E-mail",
    "Instant messaging" : "Швидкі повідомлення",
    "Phone" : "Телефон",
    "Mobile" : "Мобільний",
    "Fax" : "Факс",
    "Fax home" : "Домашній факс",
    "Fax work" : "Робочий факс",
    "Pager" : "Пейджер",
    "Voice" : "Голос",
    "Social network" : "Соціальна мережа",
    "Settings" : "Налаштування"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
